pub use crate::prelude::*;

#[derive(Deserialize, Debug)]
pub struct Params {
    file_id: Uuid,
}

pub async fn delete(
    Query(params): Query<Params>,
    State(state): State<AppState>,
    claims: Claims,
) -> Result<StatusCode, StatusCode> {
    db::file::get_permissions(params.file_id, claims.user_id, &state.pool)
        .await
        .handle_internal()?
        .can_write_guard()?;

    let deleted = db::file::delete(params.file_id, &state.pool)
        .await
        .handle_internal()?;
    if !deleted {
        return Err(StatusCode::NOT_FOUND); // Will not happen most of the time due to can write guard
    }

    state
        .storage
        .delete(params.file_id)
        .await
        .handle_internal()?;

    Ok(StatusCode::NO_CONTENT)
}
